@@ -2,8 +2,10 @@ mod tcp4;
 mod udp4;
 mod icmp4;
 mod vxlan;
+mod dhcp;
 
 pub use tcp4::{TcpSeg, TcpFlow};
 pub use udp4::{UdpDgram, UdpFlow};
 pub use vxlan::{VxlanDgram, VxlanFlow};
 pub use icmp4::{IcmpDgram, IcmpFlow};
+pub use dhcp::Dhcp;
